package com.atguigu.ssyx.product.controller;


import com.atguigu.ssyx.common.result.Result;
import com.atguigu.ssyx.model.product.SkuInfo;
import com.atguigu.ssyx.product.service.SkuInfoService;
import com.atguigu.ssyx.vo.product.SkuInfoQueryVo;
import com.atguigu.ssyx.vo.product.SkuInfoVo;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * sku信息 前端控制器
 * </p>
 *
 * @author bunny
 * @since 2024-04-03
 */
@Api(value = "SkuInfo管理", tags = "商品Sku管理")
@RestController
@RequestMapping(value = "/admin/product/skuInfo")
public class SkuInfoController {
    @Autowired
    private SkuInfoService skuInfoService;

    @ApiOperation(value = "获取sku分页列表")
    @GetMapping("{page}/{limit}")
    public Result<IPage<SkuInfo>> index(
            @ApiParam(name = "page", value = "当前页码", required = true)
            @PathVariable Long page,

            @ApiParam(name = "limit", value = "每页记录数", required = true)
            @PathVariable Long limit,

            @ApiParam(name = "skuInfoQueryVo", value = "查询对象", required = false)
            SkuInfoQueryVo skuInfoQueryVo) {
        Page<SkuInfo> pageParam = new Page<>(page, limit);
        IPage<SkuInfo> pageModel = skuInfoService.selectPage(pageParam, skuInfoQueryVo);
        return Result.success(pageModel);
    }

    @ApiOperation(value = "商品添加方法")
    @PostMapping("save")
    public Result<SkuInfo> save(@RequestBody SkuInfoVo skuInfoVo) {
        skuInfoService.saveSkuInfo(skuInfoVo);
        return Result.success();
    }

    @ApiOperation(value = "获取商品SKU信息")
    @GetMapping("get/{id}")
    public Result<SkuInfoVo> get(@PathVariable Long id) {
        SkuInfoVo skuInfoVo = skuInfoService.getSkuInfoVo(id);
        return Result.success(skuInfoVo);
    }

    @ApiOperation(value = "修改商品sku信息")
    @PutMapping("update")
    public Result<SkuInfoVo> updateById(@RequestBody SkuInfoVo skuInfoVo) {
        skuInfoService.updateSkuInfo(skuInfoVo);
        return Result.success();
    }

    @ApiOperation(value = "商品SKU删除")
    @DeleteMapping("remove/{id}")
    public Result<SkuInfoVo> remove(@PathVariable Long id) {
        skuInfoService.removeById(id);
        return Result.success();
    }

    @ApiOperation(value = "根据id列表删除")
    @DeleteMapping("batchRemove")
    public Result<SkuInfoVo> batchRemove(@RequestBody List<Long> ids) {
        skuInfoService.removeByIds(ids);
        return Result.success();
    }

    @ApiOperation(value = "商品审核")
    @GetMapping("check/{skuId}/{status}")
    public Result<SkuInfo> check(@PathVariable Long skuId, @PathVariable Integer status) {
        skuInfoService.check(skuId, status);
        return Result.success();
    }

    @ApiOperation(value = "商品上架")
    @GetMapping("publish/{skuId}/{status}")
    public Result<SkuInfo> publish(@PathVariable("skuId") Long skuId,
                                   @PathVariable("status") Integer status) {
        skuInfoService.publish(skuId, status);
        return Result.success();
    }

    @ApiOperation(value = "新人专享")
    @GetMapping("isNewPerson/{skuId}/{status}")
    public Result<SkuInfo> isNewPerson(@PathVariable Long skuId, @PathVariable Integer status) {
        skuInfoService.isNewPerson(skuId, status);
        return Result.success();
    }
}

